@@ -4,9 +4,9 @@ require_relative '../../lib/sass/elf'
 
 module Sass
   module CLI
-    INTERPRETER = '/lib/ld-linux-riscv64-lp64d.so.1'
+    INTERPRETER = '/lib64/ld-linux-x86-64.so.2'
 
-    INTERPRETER_SUFFIX = '/ld-linux-riscv64-lp64d.so.1'
+    INTERPRETER_SUFFIX = '/ld-linux-x86-64.so.2'
 
     COMMAND = [
       *(ELF::INTERPRETER if ELF::INTERPRETER != INTERPRETER && ELF::INTERPRETER&.end_with?(INTERPRETER_SUFFIX)),
